from OpenGL.GL import *
from OpenGL.GLU import *
from OpenGL.GLUT import *

from pyplasm import *

# /////////////////////////////////////////////////
#SKELETON(1)(T([1,2])([-1,-19])(CUBOID([2,20])))
# /////////////////////////////////////////////////
def displayLink(): 
	glPushMatrix()
	glTranslate(-1.0,-19.0,0.0)
	glScalef(2.0,20.0,1.0)
	glTranslatef(0.5,0.5,0.5)
	glutWireCube(1.0)
	glPopMatrix()
	
# /////////////////////////////////////////////////
# return COMP([ T(2)(-18), R([1,2])(alpha * PI/180)])
# /////////////////////////////////////////////////
def displayJoint (alpha): 
	glTranslatef(0,-18,0)
	glRotatef(alpha,0,0,1)
	
# /////////////////////////////////////////////////
# return STRUCT([ link, joint(a1), link, joint(a2), link, joint(a3), link ])
# /////////////////////////////////////////////////
def displayArm(args):
    a1,a2,a3 = args
    glPushMatrix()
    displayLink()
    displayJoint(a1)
    displayLink()
    displayJoint(a2)
    displayLink()
    displayJoint(a3)
    displayLink()
    glPopMatrix()
    
# /////////////////////////////////////////////////    
def sampling(n): 
	return AA(DIV)(DISTR([range(n+1),n]))

# /////////////////////////////////////////////////
def sample (n):
    return AA(SCALARVECTPROD)(DISTL([[90,90,90], sampling(n)]))

# /////////////////////////////////////////////////
def display():
        glClear(GL_COLOR_BUFFER_BIT)
        glColor3f(1.0, 1.0, 1.0)
        gluLookAt(0.0, 0.0, 100.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0)
        # VIEW(STRUCT(AA(arm)(sample(10)))) 
        for args in sample(10): displayArm(args)
        glFlush()

# /////////////////////////////////////////////////
def reshape(w, h):
    glViewport(0, 0, w, h)
    aspectRatio = float(w) / float(h)
    if (w <= h): u,v = 1,1/aspectRatio
    else: u,v = aspectRatio, 1
    glMatrixMode(GL_PROJECTION)
    glLoadIdentity()
    glOrtho(-50.0*u, 100.0*u, -100.0*v, 50.0*v, 0.01, 1000.0)
    glMatrixMode(GL_MODELVIEW)
    glLoadIdentity() 


# /////////////////////////////////////////////////
# Main program entry point
# /////////////////////////////////////////////////
if __name__ == "__main__":
    glutInit()
    glutInitDisplayMode(GLUT_SINGLE | GLUT_RGB)
    glutInitWindowSize(400, 400)
    glutInitWindowPosition(940, 0)
    glutCreateWindow("Arm 2D")
    #glClearColor(0.0, 0.0, 0.0, 0.0)
    glShadeModel(GL_FLAT)
    glutDisplayFunc(display)
    glutReshapeFunc(reshape)
    glutMainLoop()
